# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/redis/v1/backup.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/redis/v1/backup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/mdb/redis/v1/backup.proto\x12\x19yandex.cloud.mdb.redis.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc0\x02\n\x06\x42\x61\x63kup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11source_cluster_id\x18\x04 \x01(\t\x12.\n\nstarted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12source_shard_names\x18\x06 \x03(\t\x12:\n\x04type\x18\x07 \x01(\x0e\x32,.yandex.cloud.mdb.redis.v1.Backup.BackupType\"D\n\nBackupType\x12\x1b\n\x17\x42\x41\x43KUP_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tAUTOMATED\x10\x01\x12\n\n\x06MANUAL\x10\x02\x42\x64\n\x1dyandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.redis.v1.backup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redis'
  _globals['_BACKUP']._serialized_start=103
  _globals['_BACKUP']._serialized_end=423
  _globals['_BACKUP_BACKUPTYPE']._serialized_start=355
  _globals['_BACKUP_BACKUPTYPE']._serialized_end=423
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.ai.assistants.v1.common_pb2
import yandex.cloud.ai.assistants.v1.runs.run_pb2
import yandex.cloud.ai.assistants.v1.threads.message_pb2
import yandex.cloud.ai.common.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateRunRequest(google.protobuf.message.Message):
    """Request message for creating a new run."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ASSISTANT_ID_FIELD_NUMBER: builtins.int
    THREAD_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ADDITIONAL_MESSAGES_FIELD_NUMBER: builtins.int
    CUSTOM_PROMPT_TRUNCATION_OPTIONS_FIELD_NUMBER: builtins.int
    CUSTOM_COMPLETION_OPTIONS_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    TOOLS_FIELD_NUMBER: builtins.int
    assistant_id: builtins.str
    """ID of the assistant for which the run is being created"""
    thread_id: builtins.str
    """ID of the thread associated with the run."""
    stream: builtins.bool
    """Enables streaming of intermediate events, such as partial messages."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Set of key-value pairs to label the run."""

    @property
    def additional_messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.threads.message_pb2.MessageData]:
        """Additional messages that will be written to the thread before the run starts."""

    @property
    def custom_prompt_truncation_options(self) -> yandex.cloud.ai.assistants.v1.common_pb2.PromptTruncationOptions:
        """Configuration options for truncating the prompt when the token count exceeds a specified limit.
        If specified, these options will override the assistant's prompt truncation settings for this run.
        """

    @property
    def custom_completion_options(self) -> yandex.cloud.ai.assistants.v1.common_pb2.CompletionOptions:
        """Configuration options for completion generation.
        If specified, these options will override the assistant's completion settings for this run.
        """

    @property
    def tools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.common_pb2.Tool]:
        """List of tools that are available for the assistant to use in this run."""

    def __init__(
        self,
        *,
        assistant_id: builtins.str = ...,
        thread_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        additional_messages: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.threads.message_pb2.MessageData] | None = ...,
        custom_prompt_truncation_options: yandex.cloud.ai.assistants.v1.common_pb2.PromptTruncationOptions | None = ...,
        custom_completion_options: yandex.cloud.ai.assistants.v1.common_pb2.CompletionOptions | None = ...,
        stream: builtins.bool = ...,
        tools: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.common_pb2.Tool] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["custom_completion_options", b"custom_completion_options", "custom_prompt_truncation_options", b"custom_prompt_truncation_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_messages", b"additional_messages", "assistant_id", b"assistant_id", "custom_completion_options", b"custom_completion_options", "custom_prompt_truncation_options", b"custom_prompt_truncation_options", "labels", b"labels", "stream", b"stream", "thread_id", b"thread_id", "tools", b"tools"]) -> None: ...

global___CreateRunRequest = CreateRunRequest

@typing.final
class ListenRunRequest(google.protobuf.message.Message):
    """Request message for listing to a run events."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUN_ID_FIELD_NUMBER: builtins.int
    EVENTS_START_IDX_FIELD_NUMBER: builtins.int
    run_id: builtins.str
    """ID of the run to listen to."""
    @property
    def events_start_idx(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Starting index for events. If provided, listening will start from this event."""

    def __init__(
        self,
        *,
        run_id: builtins.str = ...,
        events_start_idx: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["events_start_idx", b"events_start_idx"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["events_start_idx", b"events_start_idx", "run_id", b"run_id"]) -> None: ...

global___ListenRunRequest = ListenRunRequest

@typing.final
class AttachRunRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUN_ID_FIELD_NUMBER: builtins.int
    EVENTS_START_IDX_FIELD_NUMBER: builtins.int
    TOOL_RESULT_LIST_FIELD_NUMBER: builtins.int
    run_id: builtins.str
    """ID of the run to listen to."""
    @property
    def events_start_idx(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Starting index for events. If provided, listening will start from this event."""

    @property
    def tool_result_list(self) -> yandex.cloud.ai.assistants.v1.common_pb2.ToolResultList:
        """A list of tool results to submit to the run, such as the output of a function call."""

    def __init__(
        self,
        *,
        run_id: builtins.str = ...,
        events_start_idx: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        tool_result_list: yandex.cloud.ai.assistants.v1.common_pb2.ToolResultList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Event", b"Event", "events_start_idx", b"events_start_idx", "tool_result_list", b"tool_result_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Event", b"Event", "events_start_idx", b"events_start_idx", "run_id", b"run_id", "tool_result_list", b"tool_result_list"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Event", b"Event"]) -> typing.Literal["tool_result_list"] | None: ...

global___AttachRunRequest = AttachRunRequest

@typing.final
class GetRunRequest(google.protobuf.message.Message):
    """Request message for retrieving a specific run by its ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUN_ID_FIELD_NUMBER: builtins.int
    run_id: builtins.str
    """ID of the run to retrieve."""
    def __init__(
        self,
        *,
        run_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["run_id", b"run_id"]) -> None: ...

global___GetRunRequest = GetRunRequest

@typing.final
class GetLastRunByThreadRequest(google.protobuf.message.Message):
    """Request message for retrieving the last run associated with a specific thread."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THREAD_ID_FIELD_NUMBER: builtins.int
    thread_id: builtins.str
    """ID of the thread for which the last run is being fetched."""
    def __init__(
        self,
        *,
        thread_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thread_id", b"thread_id"]) -> None: ...

global___GetLastRunByThreadRequest = GetLastRunByThreadRequest

@typing.final
class ListRunsRequest(google.protobuf.message.Message):
    """Request message for listing runs."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID from which to list runs."""
    page_size: builtins.int
    """Maximum number of threads to return per page."""
    page_token: builtins.str
    """Token to retrieve the next page of results."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListRunsRequest = ListRunsRequest

@typing.final
class ListRunsResponse(google.protobuf.message.Message):
    """Response message for the list operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results."""
    @property
    def runs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run]:
        """List of runs in the specified folder."""

    def __init__(
        self,
        *,
        runs: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "runs", b"runs"]) -> None: ...

global___ListRunsResponse = ListRunsResponse

@typing.final
class StreamCursor(google.protobuf.message.Message):
    """Represents the cursor position in a stream of events."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENT_EVENT_IDX_FIELD_NUMBER: builtins.int
    NUM_USER_EVENTS_RECEIVED_FIELD_NUMBER: builtins.int
    current_event_idx: builtins.int
    """Index of the current event in the stream."""
    num_user_events_received: builtins.int
    """The number of user events received so far."""
    def __init__(
        self,
        *,
        current_event_idx: builtins.int = ...,
        num_user_events_received: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["current_event_idx", b"current_event_idx", "num_user_events_received", b"num_user_events_received"]) -> None: ...

global___StreamCursor = StreamCursor

@typing.final
class StreamEvent(google.protobuf.message.Message):
    """Represents an event in the stream of a run."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _EventType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EventTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StreamEvent._EventType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        EVENT_TYPE_UNSPECIFIED: StreamEvent._EventType.ValueType  # 0
        """Unspecified event type."""
        PARTIAL_MESSAGE: StreamEvent._EventType.ValueType  # 1
        """Partial message is available."""
        ERROR: StreamEvent._EventType.ValueType  # 2
        """Run has failed due to an error."""
        DONE: StreamEvent._EventType.ValueType  # 3
        """The run has completed."""
        TOOL_CALLS: StreamEvent._EventType.ValueType  # 4
        """The run is waiting for tool calls to be executed and their results to be submitted."""

    class EventType(_EventType, metaclass=_EventTypeEnumTypeWrapper):
        """Enum representing events that can occur in the stream."""

    EVENT_TYPE_UNSPECIFIED: StreamEvent.EventType.ValueType  # 0
    """Unspecified event type."""
    PARTIAL_MESSAGE: StreamEvent.EventType.ValueType  # 1
    """Partial message is available."""
    ERROR: StreamEvent.EventType.ValueType  # 2
    """Run has failed due to an error."""
    DONE: StreamEvent.EventType.ValueType  # 3
    """The run has completed."""
    TOOL_CALLS: StreamEvent.EventType.ValueType  # 4
    """The run is waiting for tool calls to be executed and their results to be submitted."""

    EVENT_TYPE_FIELD_NUMBER: builtins.int
    STREAM_CURSOR_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    PARTIAL_MESSAGE_FIELD_NUMBER: builtins.int
    COMPLETED_MESSAGE_FIELD_NUMBER: builtins.int
    TOOL_CALL_LIST_FIELD_NUMBER: builtins.int
    event_type: global___StreamEvent.EventType.ValueType
    """The type of event."""
    @property
    def stream_cursor(self) -> global___StreamCursor:
        """The current position in the stream."""

    @property
    def error(self) -> yandex.cloud.ai.common.common_pb2.Error:
        """Error information if the run has failed."""

    @property
    def partial_message(self) -> yandex.cloud.ai.assistants.v1.threads.message_pb2.MessageContent:
        """Partially generated message."""

    @property
    def completed_message(self) -> yandex.cloud.ai.assistants.v1.threads.message_pb2.Message:
        """Final message generated by an assistant if a run has completed successfully."""

    @property
    def tool_call_list(self) -> yandex.cloud.ai.assistants.v1.common_pb2.ToolCallList:
        """A list of tool calls requested by the assistant."""

    def __init__(
        self,
        *,
        event_type: global___StreamEvent.EventType.ValueType = ...,
        stream_cursor: global___StreamCursor | None = ...,
        error: yandex.cloud.ai.common.common_pb2.Error | None = ...,
        partial_message: yandex.cloud.ai.assistants.v1.threads.message_pb2.MessageContent | None = ...,
        completed_message: yandex.cloud.ai.assistants.v1.threads.message_pb2.Message | None = ...,
        tool_call_list: yandex.cloud.ai.assistants.v1.common_pb2.ToolCallList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["EventData", b"EventData", "completed_message", b"completed_message", "error", b"error", "partial_message", b"partial_message", "stream_cursor", b"stream_cursor", "tool_call_list", b"tool_call_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["EventData", b"EventData", "completed_message", b"completed_message", "error", b"error", "event_type", b"event_type", "partial_message", b"partial_message", "stream_cursor", b"stream_cursor", "tool_call_list", b"tool_call_list"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["EventData", b"EventData"]) -> typing.Literal["error", "partial_message", "completed_message", "tool_call_list"] | None: ...

global___StreamEvent = StreamEvent

@typing.final
class SubmitToRunRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUN_ID_FIELD_NUMBER: builtins.int
    TOOL_RESULT_LIST_FIELD_NUMBER: builtins.int
    run_id: builtins.str
    """ID of the run to submit to."""
    @property
    def tool_result_list(self) -> yandex.cloud.ai.assistants.v1.common_pb2.ToolResultList:
        """A list of tool results to submit to the run, such as the output of a function call."""

    def __init__(
        self,
        *,
        run_id: builtins.str = ...,
        tool_result_list: yandex.cloud.ai.assistants.v1.common_pb2.ToolResultList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Event", b"Event", "tool_result_list", b"tool_result_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Event", b"Event", "run_id", b"run_id", "tool_result_list", b"tool_result_list"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Event", b"Event"]) -> typing.Literal["tool_result_list"] | None: ...

global___SubmitToRunRequest = SubmitToRunRequest

@typing.final
class SubmitToRunResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SubmitToRunResponse = SubmitToRunResponse



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.compute.v1 import snapshot_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__pb2
from yandex.cloud.compute.v1 import snapshot_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/compute/v1/snapshot_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SnapshotServiceStub(object):
    """A set of methods for managing Snapshot resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotService/Get',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.GetSnapshotRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__pb2.Snapshot.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotService/List',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotsResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotService/Create',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.CreateSnapshotRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotService/Update',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.UpdateSnapshotRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotService/Delete',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.DeleteSnapshotRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotOperationsResponse.FromString,
                _registered_method=True)
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                _registered_method=True)
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class SnapshotServiceServicer(object):
    """A set of methods for managing Snapshot resources.
    """

    def Get(self, request, context):
        """Returns the specified Snapshot resource.

        To get the list of available Snapshot resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Snapshot resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a snapshot of the specified disk.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified snapshot.

        Values of omitted parameters are not changed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified snapshot.

        Deleting a snapshot removes its data permanently and is irreversible.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified snapshot.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """access

        Lists access bindings for the snapshot.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the snapshot.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the snapshot.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SnapshotServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.GetSnapshotRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__pb2.Snapshot.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.CreateSnapshotRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.UpdateSnapshotRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.DeleteSnapshotRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.compute.v1.SnapshotService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.compute.v1.SnapshotService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SnapshotService(object):
    """A set of methods for managing Snapshot resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotService/Get',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.GetSnapshotRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__pb2.Snapshot.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotService/List',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotService/Create',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.CreateSnapshotRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotService/Update',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.UpdateSnapshotRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotService/Delete',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.DeleteSnapshotRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotService/ListOperations',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__service__pb2.ListSnapshotOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TextContent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGES_FIELD_NUMBER: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Message]: ...
    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[global___Message] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["messages", b"messages"]) -> None: ...

global___TextContent = TextContent

@typing.final
class Message(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def text(self) -> global___TextPayload: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        text: global___TextPayload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["payload", b"payload", "text", b"text", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["payload", b"payload", "text", b"text", "timestamp", b"timestamp", "user_id", b"user_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["payload", b"payload"]) -> typing.Literal["text"] | None: ...

global___Message = Message

@typing.final
class TextPayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text", b"text"]) -> None: ...

global___TextPayload = TextPayload



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/foundation_models/v1/text_generation/text_generation_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/foundation_models/v1/text_generation/text_generation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.ai.foundation_models.v1 import text_common_pb2 as yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__common__pb2
from yandex.cloud.ai.foundation_models.v1 import batch_inference_task_status_pb2 as yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_batch__inference__task__status__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRyandex/cloud/ai/foundation_models/v1/text_generation/text_generation_service.proto\x12$yandex.cloud.ai.foundation_models.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x36yandex/cloud/ai/foundation_models/v1/text_common.proto\x1a\x46yandex/cloud/ai/foundation_models/v1/batch_inference_task_status.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\"\xe9\x02\n\x11\x43ompletionRequest\x12\x11\n\tmodel_uri\x18\x01 \x01(\t\x12S\n\x12\x63ompletion_options\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.ai.foundation_models.v1.CompletionOptions\x12?\n\x08messages\x18\x03 \x03(\x0b\x32-.yandex.cloud.ai.foundation_models.v1.Message\x12\x39\n\x05tools\x18\x04 \x03(\x0b\x32*.yandex.cloud.ai.foundation_models.v1.Tool\x12\x15\n\x0bjson_object\x18\x05 \x01(\x08H\x00\x12G\n\x0bjson_schema\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.ai.foundation_models.v1.JsonSchemaH\x00\x42\x10\n\x0eResponseFormat\"\xb7\x01\n\x12\x43ompletionResponse\x12G\n\x0c\x61lternatives\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.ai.foundation_models.v1.Alternative\x12\x41\n\x05usage\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.ai.foundation_models.v1.ContentUsage\x12\x15\n\rmodel_version\x18\x03 \x01(\t\"\xaf\x01\n\x16\x42\x61tchCompletionRequest\x12\x11\n\tmodel_uri\x18\x01 \x01(\t\x12S\n\x12\x63ompletion_options\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.ai.foundation_models.v1.CompletionOptions\x12\x1b\n\x11source_dataset_id\x18\x03 \x01(\tH\x00\x42\x10\n\x0erequest_format\"\xb1\x01\n\x17\x42\x61tchCompletionMetadata\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12S\n\x0btask_status\x18\x02 \x01(\x0e\x32>.yandex.cloud.ai.foundation_models.v1.BatchInferenceTaskStatus\x12\x19\n\x11\x63ompleted_batches\x18\x03 \x01(\x03\x12\x15\n\rtotal_batches\x18\x04 \x01(\x03\"\x9a\x01\n\x17\x42\x61tchCompletionResponse\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12S\n\x0btask_status\x18\x02 \x01(\x0e\x32>.yandex.cloud.ai.foundation_models.v1.BatchInferenceTaskStatus\x12\x19\n\x11result_dataset_id\x18\x03 \x01(\t\"2\n\x0fTokenizeRequest\x12\x11\n\tmodel_uri\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"f\n\x10TokenizeResponse\x12;\n\x06tokens\x18\x01 \x03(\x0b\x32+.yandex.cloud.ai.foundation_models.v1.Token\x12\x15\n\rmodel_version\x18\x02 \x01(\t2\xc7\x01\n\x15TextGenerationService\x12\xad\x01\n\nCompletion\x12\x37.yandex.cloud.ai.foundation_models.v1.CompletionRequest\x1a\x38.yandex.cloud.ai.foundation_models.v1.CompletionResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/foundationModels/v1/completion:\x01*0\x01\x32\xd0\x01\n\x1aTextGenerationAsyncService\x12\xb1\x01\n\nCompletion\x12\x37.yandex.cloud.ai.foundation_models.v1.CompletionRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x14\x12\x12\x43ompletionResponse\x82\xd3\xe4\x93\x02)\"$/foundationModels/v1/completionAsync:\x01*2\xf3\x01\n\x1aTextGenerationBatchService\x12\xd4\x01\n\nCompletion\x12<.yandex.cloud.ai.foundation_models.v1.BatchCompletionRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*2\n\x17\x42\x61tchCompletionMetadata\x12\x17\x42\x61tchCompletionResponse\x82\xd3\xe4\x93\x02)\"$/foundationModels/v1/completionBatch:\x01*2\xf4\x02\n\x10TokenizerService\x12\xa3\x01\n\x08Tokenize\x12\x35.yandex.cloud.ai.foundation_models.v1.TokenizeRequest\x1a\x36.yandex.cloud.ai.foundation_models.v1.TokenizeResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/foundationModels/v1/tokenize:\x01*\x12\xb9\x01\n\x12TokenizeCompletion\x12\x37.yandex.cloud.ai.foundation_models.v1.CompletionRequest\x1a\x36.yandex.cloud.ai.foundation_models.v1.TokenizeResponse\"2\x82\xd3\xe4\x93\x02,\"\'/foundationModels/v1/tokenizeCompletion:\x01*B\x96\x01\n(yandex.cloud.api.ai.foundation_models.v1Zjgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_generation;foundation_modelsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.ai.foundation_models.v1Zjgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_generation;foundation_models'
  _globals['_TEXTGENERATIONSERVICE'].methods_by_name['Completion']._loaded_options = None
  _globals['_TEXTGENERATIONSERVICE'].methods_by_name['Completion']._serialized_options = b'\202\323\344\223\002$\"\037/foundationModels/v1/completion:\001*'
  _globals['_TEXTGENERATIONASYNCSERVICE'].methods_by_name['Completion']._loaded_options = None
  _globals['_TEXTGENERATIONASYNCSERVICE'].methods_by_name['Completion']._serialized_options = b'\262\322*\024\022\022CompletionResponse\202\323\344\223\002)\"$/foundationModels/v1/completionAsync:\001*'
  _globals['_TEXTGENERATIONBATCHSERVICE'].methods_by_name['Completion']._loaded_options = None
  _globals['_TEXTGENERATIONBATCHSERVICE'].methods_by_name['Completion']._serialized_options = b'\262\322*2\n\027BatchCompletionMetadata\022\027BatchCompletionResponse\202\323\344\223\002)\"$/foundationModels/v1/completionBatch:\001*'
  _globals['_TOKENIZERSERVICE'].methods_by_name['Tokenize']._loaded_options = None
  _globals['_TOKENIZERSERVICE'].methods_by_name['Tokenize']._serialized_options = b'\202\323\344\223\002\"\"\035/foundationModels/v1/tokenize:\001*'
  _globals['_TOKENIZERSERVICE'].methods_by_name['TokenizeCompletion']._loaded_options = None
  _globals['_TOKENIZERSERVICE'].methods_by_name['TokenizeCompletion']._serialized_options = b'\202\323\344\223\002,\"\'/foundationModels/v1/tokenizeCompletion:\001*'
  _globals['_COMPLETIONREQUEST']._serialized_start=357
  _globals['_COMPLETIONREQUEST']._serialized_end=718
  _globals['_COMPLETIONRESPONSE']._serialized_start=721
  _globals['_COMPLETIONRESPONSE']._serialized_end=904
  _globals['_BATCHCOMPLETIONREQUEST']._serialized_start=907
  _globals['_BATCHCOMPLETIONREQUEST']._serialized_end=1082
  _globals['_BATCHCOMPLETIONMETADATA']._serialized_start=1085
  _globals['_BATCHCOMPLETIONMETADATA']._serialized_end=1262
  _globals['_BATCHCOMPLETIONRESPONSE']._serialized_start=1265
  _globals['_BATCHCOMPLETIONRESPONSE']._serialized_end=1419
  _globals['_TOKENIZEREQUEST']._serialized_start=1421
  _globals['_TOKENIZEREQUEST']._serialized_end=1471
  _globals['_TOKENIZERESPONSE']._serialized_start=1473
  _globals['_TOKENIZERESPONSE']._serialized_end=1575
  _globals['_TEXTGENERATIONSERVICE']._serialized_start=1578
  _globals['_TEXTGENERATIONSERVICE']._serialized_end=1777
  _globals['_TEXTGENERATIONASYNCSERVICE']._serialized_start=1780
  _globals['_TEXTGENERATIONASYNCSERVICE']._serialized_end=1988
  _globals['_TEXTGENERATIONBATCHSERVICE']._serialized_start=1991
  _globals['_TEXTGENERATIONBATCHSERVICE']._serialized_end=2234
  _globals['_TOKENIZERSERVICE']._serialized_start=2237
  _globals['_TOKENIZERSERVICE']._serialized_end=2609
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ydb/v1/storage_type_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ydb/v1/storage_type_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.ydb.v1 import storage_type_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_storage__type__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/ydb/v1/storage_type_service.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/ydb/v1/storage_type.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x15GetStorageTypeRequest\x12\x1d\n\x0fstorage_type_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x17ListStorageTypesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x18ListStorageTypesResponse\x12\x37\n\rstorage_types\x18\x01 \x03(\x0b\x32 .yandex.cloud.ydb.v1.StorageType\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9e\x02\n\x12StorageTypeService\x12\x83\x01\n\x03Get\x12*.yandex.cloud.ydb.v1.GetStorageTypeRequest\x1a .yandex.cloud.ydb.v1.StorageType\".\x82\xd3\xe4\x93\x02(\x12&/ydb/v1/storageTypes/{storage_type_id}\x12\x81\x01\n\x04List\x12,.yandex.cloud.ydb.v1.ListStorageTypesRequest\x1a-.yandex.cloud.ydb.v1.ListStorageTypesResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/ydb/v1/storageTypesBV\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ydb.v1.storage_type_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb'
  _globals['_GETSTORAGETYPEREQUEST'].fields_by_name['storage_type_id']._loaded_options = None
  _globals['_GETSTORAGETYPEREQUEST'].fields_by_name['storage_type_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTSTORAGETYPESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSTORAGETYPESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTSTORAGETYPESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSTORAGETYPESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STORAGETYPESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_STORAGETYPESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/ydb/v1/storageTypes/{storage_type_id}'
  _globals['_STORAGETYPESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_STORAGETYPESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/ydb/v1/storageTypes'
  _globals['_GETSTORAGETYPEREQUEST']._serialized_start=172
  _globals['_GETSTORAGETYPEREQUEST']._serialized_end=226
  _globals['_LISTSTORAGETYPESREQUEST']._serialized_start=228
  _globals['_LISTSTORAGETYPESREQUEST']._serialized_end=315
  _globals['_LISTSTORAGETYPESRESPONSE']._serialized_start=317
  _globals['_LISTSTORAGETYPESRESPONSE']._serialized_end=425
  _globals['_STORAGETYPESERVICE']._serialized_start=428
  _globals['_STORAGETYPESERVICE']._serialized_end=714
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.containerregistry.v1.image_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListImagesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to list Docker images in.

    [registry_id] is ignored if a [ListImagesRequest.repository_name] is specified in the request.

    To get the registry ID use a [RegistryService.List] request.
    """
    repository_name: builtins.str
    """Name of the repository to list Docker images in.

    To get the repository name use a [RepositoryService.List] request.
    """
    folder_id: builtins.str
    """ID of the folder to list Docker images in.

    [folder_id] is ignored if a [ListImagesRequest.repository_name] or a [ListImagesRequest.registry_id] are specified in the request.

    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListImagesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListImagesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Image.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be a maximum of 256 characters long and match the regular expression `[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))`.
    """
    order_by: builtins.str
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        repository_name: builtins.str = ...,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "registry_id", b"registry_id", "repository_name", b"repository_name"]) -> None: ...

global___ListImagesRequest = ListImagesRequest

@typing.final
class ListImagesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListImagesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListImagesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.image_pb2.Image]:
        """List of Image resources."""

    def __init__(
        self,
        *,
        images: collections.abc.Iterable[yandex.cloud.containerregistry.v1.image_pb2.Image] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["images", b"images", "next_page_token", b"next_page_token"]) -> None: ...

global___ListImagesResponse = ListImagesResponse

@typing.final
class GetImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Docker image resource to return.

    To get the Docker image ID use a [ImageService.List] request.
    """
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___GetImageRequest = GetImageRequest

@typing.final
class DeleteImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Docker image to delete.

    To get Docker image ID use a [ImageService.List] request.
    """
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___DeleteImageRequest = DeleteImageRequest

@typing.final
class DeleteImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Docker image that is being deleted."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___DeleteImageMetadata = DeleteImageMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ScanPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    REGISTRY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Output only. ID of the scan policy."""
    registry_id: builtins.str
    """ID of the registry that the scan policy belongs to.
    Required. The maximum string length in characters is 50.
    """
    name: builtins.str
    """Name of the scan policy."""
    description: builtins.str
    """Description of the scan policy.
    The maximum string length in characters is 256.
    """
    disabled: builtins.bool
    """Turns off scan policy."""
    @property
    def rules(self) -> global___ScanRules:
        """The rules of scan policy."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Output only. Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        registry_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        rules: global___ScanRules | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "rules", b"rules"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "disabled", b"disabled", "id", b"id", "name", b"name", "registry_id", b"registry_id", "rules", b"rules"]) -> None: ...

global___ScanPolicy = ScanPolicy

@typing.final
class ScanRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUSH_RULE_FIELD_NUMBER: builtins.int
    SCHEDULE_RULES_FIELD_NUMBER: builtins.int
    @property
    def push_rule(self) -> global___PushRule:
        """Description of on-push scan rule."""

    @property
    def schedule_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScheduledRule]:
        """Description of time based rescan rule."""

    def __init__(
        self,
        *,
        push_rule: global___PushRule | None = ...,
        schedule_rules: collections.abc.Iterable[global___ScheduledRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["push_rule", b"push_rule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["push_rule", b"push_rule", "schedule_rules", b"schedule_rules"]) -> None: ...

global___ScanRules = ScanRules

@typing.final
class PushRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_PREFIXES_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    """Turns off scan rule."""
    @property
    def repository_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of repositories that are scanned with rule. Child repositories are included into parent node. "*" - means all repositories in registry"""

    def __init__(
        self,
        *,
        repository_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "repository_prefixes", b"repository_prefixes"]) -> None: ...

global___PushRule = PushRule

@typing.final
class ScheduledRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_PREFIXES_FIELD_NUMBER: builtins.int
    RESCAN_PERIOD_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    """Turns off scan rule."""
    @property
    def repository_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of repositories that are scanned with rule. Child repositories are included into parent node. "*" - means all repositories in registry"""

    @property
    def rescan_period(self) -> google.protobuf.duration_pb2.Duration:
        """Period of time since last scan to trigger automatic rescan."""

    def __init__(
        self,
        *,
        repository_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        rescan_period: google.protobuf.duration_pb2.Duration | None = ...,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rescan_period", b"rescan_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "repository_prefixes", b"repository_prefixes", "rescan_period", b"rescan_period"]) -> None: ...

global___ScheduledRule = ScheduledRule



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/kafka/v1/topic.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/kafka/v1/topic.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.mdb.kafka.v1 import common_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/mdb/kafka/v1/topic.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a google/protobuf/descriptor.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a&yandex/cloud/mdb/kafka/v1/common.proto\"\xd3\x02\n\x05Topic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12/\n\npartitions\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n\x10topic_config_2_8\x18\x07 \x01(\x0b\x32).yandex.cloud.mdb.kafka.v1.TopicConfig2_8H\x00R\x0ftopicConfig_2_8\x12P\n\x0etopic_config_3\x18\x08 \x01(\x0b\x32\'.yandex.cloud.mdb.kafka.v1.TopicConfig3H\x00R\rtopicConfig_3B\x0e\n\x0ctopic_configJ\x04\x08\x05\x10\x07\"\xc3\x02\n\tTopicSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\npartitions\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12replication_factor\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n\x10topic_config_2_8\x18\x06 \x01(\x0b\x32).yandex.cloud.mdb.kafka.v1.TopicConfig2_8H\x00R\x0ftopicConfig_2_8\x12P\n\x0etopic_config_3\x18\x07 \x01(\x0b\x32\'.yandex.cloud.mdb.kafka.v1.TopicConfig3H\x00R\rtopicConfig_3B\x0e\n\x0ctopic_configJ\x04\x08\x04\x10\x06\"\x8c\x07\n\x0eTopicConfig2_8\x12O\n\x0e\x63leanup_policy\x18\x01 \x01(\x0e\x32\x37.yandex.cloud.mdb.kafka.v1.TopicConfig2_8.CleanupPolicy\x12\x44\n\x10\x63ompression_type\x18\x02 \x01(\x0e\x32*.yandex.cloud.mdb.kafka.v1.CompressionType\x12\x38\n\x13\x64\x65lete_retention_ms\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x66ile_delete_delay_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x66lush_messages\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08\x66lush_ms\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15min_compaction_lag_ms\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0fretention_bytes\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cretention_ms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11max_message_bytes\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13min_insync_replicas\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rsegment_bytes\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\x0bpreallocate\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x8d\x01\n\rCleanupPolicy\x12\x1e\n\x1a\x43LEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LEANUP_POLICY_DELETE\x10\x01\x12\x1a\n\x16\x43LEANUP_POLICY_COMPACT\x10\x02\x12%\n!CLEANUP_POLICY_COMPACT_AND_DELETE\x10\x03\"\x88\x07\n\x0cTopicConfig3\x12M\n\x0e\x63leanup_policy\x18\x01 \x01(\x0e\x32\x35.yandex.cloud.mdb.kafka.v1.TopicConfig3.CleanupPolicy\x12\x44\n\x10\x63ompression_type\x18\x02 \x01(\x0e\x32*.yandex.cloud.mdb.kafka.v1.CompressionType\x12\x38\n\x13\x64\x65lete_retention_ms\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x66ile_delete_delay_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x66lush_messages\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08\x66lush_ms\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15min_compaction_lag_ms\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0fretention_bytes\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cretention_ms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11max_message_bytes\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13min_insync_replicas\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rsegment_bytes\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\x0bpreallocate\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x8d\x01\n\rCleanupPolicy\x12\x1e\n\x1a\x43LEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LEANUP_POLICY_DELETE\x10\x01\x12\x1a\n\x16\x43LEANUP_POLICY_COMPACT\x10\x02\x12%\n!CLEANUP_POLICY_COMPACT_AND_DELETE\x10\x03\x42\x64\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.topic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _globals['_TOPIC']._serialized_start=175
  _globals['_TOPIC']._serialized_end=514
  _globals['_TOPICSPEC']._serialized_start=517
  _globals['_TOPICSPEC']._serialized_end=840
  _globals['_TOPICCONFIG2_8']._serialized_start=843
  _globals['_TOPICCONFIG2_8']._serialized_end=1751
  _globals['_TOPICCONFIG2_8_CLEANUPPOLICY']._serialized_start=1610
  _globals['_TOPICCONFIG2_8_CLEANUPPOLICY']._serialized_end=1751
  _globals['_TOPICCONFIG3']._serialized_start=1754
  _globals['_TOPICCONFIG3']._serialized_end=2658
  _globals['_TOPICCONFIG3_CLEANUPPOLICY']._serialized_start=1610
  _globals['_TOPICCONFIG3_CLEANUPPOLICY']._serialized_end=1751
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.dataproc.v1.job_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to request a job from."""
    job_id: builtins.str
    """ID of the job to return.

    To get a job ID make a [JobService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id"]) -> None: ...

global___GetJobRequest = GetJobRequest

@typing.final
class ListJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to list jobs for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListJobsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListJobsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters jobs listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [Job.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-job`.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListJobsRequest = ListJobsRequest

@typing.final
class ListJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListJobsRequest.page_size], use `next_page_token` as the value
    for the [ListJobsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dataproc.v1.job_pb2.Job]:
        """List of jobs for the specified cluster."""

    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[yandex.cloud.dataproc.v1.job_pb2.Job] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["jobs", b"jobs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListJobsResponse = ListJobsResponse

@typing.final
class CreateJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MAPREDUCE_JOB_FIELD_NUMBER: builtins.int
    SPARK_JOB_FIELD_NUMBER: builtins.int
    PYSPARK_JOB_FIELD_NUMBER: builtins.int
    HIVE_JOB_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to create a job for."""
    name: builtins.str
    """Name of the job."""
    @property
    def mapreduce_job(self) -> yandex.cloud.dataproc.v1.job_pb2.MapreduceJob:
        """Specification for a MapReduce job."""

    @property
    def spark_job(self) -> yandex.cloud.dataproc.v1.job_pb2.SparkJob:
        """Specification for a Spark job."""

    @property
    def pyspark_job(self) -> yandex.cloud.dataproc.v1.job_pb2.PysparkJob:
        """Specification for a PySpark job."""

    @property
    def hive_job(self) -> yandex.cloud.dataproc.v1.job_pb2.HiveJob:
        """Specification for a Hive job."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
        mapreduce_job: yandex.cloud.dataproc.v1.job_pb2.MapreduceJob | None = ...,
        spark_job: yandex.cloud.dataproc.v1.job_pb2.SparkJob | None = ...,
        pyspark_job: yandex.cloud.dataproc.v1.job_pb2.PysparkJob | None = ...,
        hive_job: yandex.cloud.dataproc.v1.job_pb2.HiveJob | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hive_job", b"hive_job", "job_spec", b"job_spec", "mapreduce_job", b"mapreduce_job", "pyspark_job", b"pyspark_job", "spark_job", b"spark_job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "hive_job", b"hive_job", "job_spec", b"job_spec", "mapreduce_job", b"mapreduce_job", "name", b"name", "pyspark_job", b"pyspark_job", "spark_job", b"spark_job"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["job_spec", b"job_spec"]) -> typing.Literal["mapreduce_job", "spark_job", "pyspark_job", "hive_job"] | None: ...

global___CreateJobRequest = CreateJobRequest

@typing.final
class CreateJobMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that the job is being created for."""
    job_id: builtins.str
    """ID of the job being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id"]) -> None: ...

global___CreateJobMetadata = CreateJobMetadata

@typing.final
class CancelJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the Dataproc cluster."""
    job_id: builtins.str
    """Required. ID of the Dataproc job to cancel."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id"]) -> None: ...

global___CancelJobRequest = CancelJobRequest

@typing.final
class ListJobLogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that the job is being created for."""
    job_id: builtins.str
    """ID of the job being created."""
    page_size: builtins.int
    """The maximum bytes of job log per response to return. If the number of available
    bytes is larger than [page_size], the service returns a [ListJobLogResponse.next_page_token]
    that can be used to get the next page of output in subsequent list requests.
    Default value: 1048576.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListJobLogResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListJobLogRequest = ListJobLogRequest

@typing.final
class ListJobLogResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    content: builtins.str
    """Requested part of Data Proc Job log."""
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListLog requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListLog request. Subsequent ListLog
    requests will have their own `next_page_token` to continue paging through the results.
    """
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "next_page_token", b"next_page_token"]) -> None: ...

global___ListJobLogResponse = ListJobLogResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.mdb.elasticsearch.v1.config.elasticsearch_pb2
import yandex.cloud.mdb.elasticsearch.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """An Elasticsearch cluster resource.
    For more information, see the [Concepts](/docs/managed-elasticsearch/concepts) section of the documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Environment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENVIRONMENT_UNSPECIFIED: Cluster._Environment.ValueType  # 0
        PRODUCTION: Cluster._Environment.ValueType  # 1
        """Stable environment with a conservative update policy when only hotfixes are applied during regular maintenance."""
        PRESTABLE: Cluster._Environment.ValueType  # 2
        """Environment with a more aggressive update policy when new versions are rolled out irrespective of backward compatibility."""

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper): ...
    ENVIRONMENT_UNSPECIFIED: Cluster.Environment.ValueType  # 0
    PRODUCTION: Cluster.Environment.ValueType  # 1
    """Stable environment with a conservative update policy when only hotfixes are applied during regular maintenance."""
    PRESTABLE: Cluster.Environment.ValueType  # 2
    """Environment with a more aggressive update policy when new versions are rolled out irrespective of backward compatibility."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """State of the cluster is unknown ([Host.health] of all hosts in the cluster is `UNKNOWN`)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive and well ([Host.health] of all hosts in the cluster is `ALIVE`)."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable ([Host.health] of all hosts in the cluster is `DEAD`)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is in degraded state ([Host.health] of at least one of the hosts in the cluster is not `ALIVE`)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """State of the cluster is unknown ([Host.health] of all hosts in the cluster is `UNKNOWN`)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive and well ([Host.health] of all hosts in the cluster is `ALIVE`)."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable ([Host.health] of all hosts in the cluster is `DEAD`)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is in degraded state ([Host.health] of at least one of the hosts in the cluster is not `ALIVE`)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Elasticsearch cluster.
    This ID is assigned at creation time.
    """
    folder_id: builtins.str
    """ID of the folder that the Elasticsearch cluster belongs to."""
    name: builtins.str
    """Name of the Elasticsearch cluster.
    The name must be unique within the folder. 1-63 characters long.
    """
    description: builtins.str
    """Description of the Elasticsearch cluster. 0-256 characters long."""
    environment: global___Cluster.Environment.ValueType
    """Deployment environment of the Elasticsearch cluster."""
    network_id: builtins.str
    """ID of the network that the cluster belongs to."""
    health: global___Cluster.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Current state of the cluster."""
    service_account_id: builtins.str
    """ID of the service account used for access to Object Storage."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Elasticsearch cluster as `key:value` pairs.
        A maximum of 64 labels per resource is allowed.
        """

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Description of monitoring systems relevant to the Elasticsearch cluster."""

    @property
    def config(self) -> global___ClusterConfig:
        """Configuration of the Elasticsearch cluster."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups"""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.elasticsearch.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    @property
    def planned_operation(self) -> yandex.cloud.mdb.elasticsearch.v1.maintenance_pb2.MaintenanceOperation:
        """Maintenance operation planned at nearest maintenance_window."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: global___Cluster.Environment.ValueType = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        config: global___ClusterConfig | None = ...,
        network_id: builtins.str = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        maintenance_window: yandex.cloud.mdb.elasticsearch.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.mdb.elasticsearch.v1.maintenance_pb2.MaintenanceOperation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "maintenance_window", b"maintenance_window", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network_id", b"network_id", "planned_operation", b"planned_operation", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id", "status", b"status"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Metadata of monitoring system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system charts for the Elasticsearch cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_FIELD_NUMBER: builtins.int
    EDITION_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Elasticsearch version."""
    edition: builtins.str
    """ElasticSearch edition."""
    @property
    def elasticsearch(self) -> global___Elasticsearch:
        """Configuration and resource allocation for Elasticsearch nodes."""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        elasticsearch: global___Elasticsearch | None = ...,
        edition: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["elasticsearch", b"elasticsearch"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["edition", b"edition", "elasticsearch", b"elasticsearch", "version", b"version"]) -> None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class Elasticsearch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DataNode(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ELASTICSEARCH_CONFIG_SET_7_FIELD_NUMBER: builtins.int
        RESOURCES_FIELD_NUMBER: builtins.int
        @property
        def elasticsearch_config_set_7(self) -> yandex.cloud.mdb.elasticsearch.v1.config.elasticsearch_pb2.ElasticsearchConfigSet7:
            """Elasticsearch 7.x data node configuration."""

        @property
        def resources(self) -> global___Resources:
            """Resources allocated to Elasticsearch data nodes."""

        def __init__(
            self,
            *,
            elasticsearch_config_set_7: yandex.cloud.mdb.elasticsearch.v1.config.elasticsearch_pb2.ElasticsearchConfigSet7 | None = ...,
            resources: global___Resources | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["config", b"config", "elasticsearch_config_set_7", b"elasticsearch_config_set_7", "resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["config", b"config", "elasticsearch_config_set_7", b"elasticsearch_config_set_7", "resources", b"resources"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["config", b"config"]) -> typing.Literal["elasticsearch_config_set_7"] | None: ...

    @typing.final
    class MasterNode(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOURCES_FIELD_NUMBER: builtins.int
        @property
        def resources(self) -> global___Resources:
            """Resources allocated to Elasticsearch master nodes."""

        def __init__(
            self,
            *,
            resources: global___Resources | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

    DATA_NODE_FIELD_NUMBER: builtins.int
    MASTER_NODE_FIELD_NUMBER: builtins.int
    PLUGINS_FIELD_NUMBER: builtins.int
    @property
    def data_node(self) -> global___Elasticsearch.DataNode:
        """Configuration and resource allocation for Elasticsearch data nodes."""

    @property
    def master_node(self) -> global___Elasticsearch.MasterNode:
        """Configuration and resource allocation for Elasticsearch master nodes."""

    @property
    def plugins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Cluster wide plugins"""

    def __init__(
        self,
        *,
        data_node: global___Elasticsearch.DataNode | None = ...,
        master_node: global___Elasticsearch.MasterNode | None = ...,
        plugins: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_node", b"data_node", "master_node", b"master_node"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data_node", b"data_node", "master_node", b"master_node", "plugins", b"plugins"]) -> None: ...

global___Elasticsearch = Elasticsearch

@typing.final
class Resources(google.protobuf.message.Message):
    """Computational resources."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources available to a host (CPU, memory etc.).
    All available presets are listed in the [documentation](/docs/managed-elasticsearch/concepts/instance-types).
    """
    disk_size: builtins.int
    """Volume of the storage available to a host, in bytes."""
    disk_type_id: builtins.str
    """Type of the storage environment for the host.
    All available types are listed in the [documentation](/docs/managed-elasticsearch/concepts/storage).
    """
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class Host(google.protobuf.message.Message):
    """Cluster host metadata."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Host._Type.ValueType  # 0
        """Host type is unspecified. Default value."""
        DATA_NODE: Host._Type.ValueType  # 1
        """The host is an Elasticsearch data node."""
        MASTER_NODE: Host._Type.ValueType  # 2
        """The host is an Elasticsearch master node."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Host.Type.ValueType  # 0
    """Host type is unspecified. Default value."""
    DATA_NODE: Host.Type.ValueType  # 1
    """The host is an Elasticsearch data node."""
    MASTER_NODE: Host.Type.ValueType  # 2
    """The host is an Elasticsearch master node."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Host._Health.ValueType  # 0
        """Health of the host is unknown."""
        ALIVE: Host._Health.ValueType  # 1
        """The host is performing all its functions normally."""
        DEAD: Host._Health.ValueType  # 2
        """The host is inoperable and cannot perform any of its essential functions."""
        DEGRADED: Host._Health.ValueType  # 3
        """The host is degraded and can perform only some of its essential functions."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    UNKNOWN: Host.Health.ValueType  # 0
    """Health of the host is unknown."""
    ALIVE: Host.Health.ValueType  # 1
    """The host is performing all its functions normally."""
    DEAD: Host.Health.ValueType  # 2
    """The host is inoperable and cannot perform any of its essential functions."""
    DEGRADED: Host.Health.ValueType  # 3
    """The host is degraded and can perform only some of its essential functions."""

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the host."""
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster."""
    zone_id: builtins.str
    """ID of the availability zone where the host resides."""
    type: global___Host.Type.ValueType
    """Host type."""
    health: global___Host.Health.ValueType
    """Aggregated host health data. If the field has default value, it is not returned in the response."""
    subnet_id: builtins.str
    """ID of the subnet the host resides in."""
    assign_public_ip: builtins.bool
    """The flag that defines whether a public IP address is assigned to the host.

    If the value is `true`, then this host is available on the Internet via it's public IP address.
    """
    @property
    def resources(self) -> global___Resources: ...
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Service]:
        """Services provided by the host."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        type: global___Host.Type.ValueType = ...,
        resources: global___Resources | None = ...,
        health: global___Host.Health.ValueType = ...,
        services: collections.abc.Iterable[global___Service] | None = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "cluster_id", b"cluster_id", "health", b"health", "name", b"name", "resources", b"resources", "services", b"services", "subnet_id", b"subnet_id", "type", b"type", "zone_id", b"zone_id"]) -> None: ...

global___Host = Host

@typing.final
class Service(google.protobuf.message.Message):
    """Cluster service metadata."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Service._Type.ValueType  # 0
        ELASTICSEARCH: Service._Type.ValueType  # 1
        """The Elasticsearch service."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Service.Type.ValueType  # 0
    ELASTICSEARCH: Service.Type.ValueType  # 1
    """The Elasticsearch service."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Service._Health.ValueType  # 0
        """Health of the service is unknown."""
        ALIVE: Service._Health.ValueType  # 1
        """The service is working normally."""
        DEAD: Service._Health.ValueType  # 2
        """The service is dead or unresponsive."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    UNKNOWN: Service.Health.ValueType  # 0
    """Health of the service is unknown."""
    ALIVE: Service.Health.ValueType  # 1
    """The service is working normally."""
    DEAD: Service.Health.ValueType  # 2
    """The service is dead or unresponsive."""

    TYPE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    type: global___Service.Type.ValueType
    """Type of the service provided by the host."""
    health: global___Service.Health.ValueType
    """Service health data. If the field has default value, it is not returned in the response."""
    def __init__(
        self,
        *,
        type: global___Service.Type.ValueType = ...,
        health: global___Service.Health.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["health", b"health", "type", b"type"]) -> None: ...

global___Service = Service



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.ydb.v1.database_pb2
import yandex.cloud.ydb.v1.database_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DatabaseServiceStub:
    """A set of methods for managing databases."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.GetDatabaseRequest,
        yandex.cloud.ydb.v1.database_pb2.Database,
    ]
    """Returns the specified database."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.ListDatabasesRequest,
        yandex.cloud.ydb.v1.database_service_pb2.ListDatabasesResponse,
    ]
    """Retrieves a list of databases."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.CreateDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new database."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.UpdateDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Modifies the specified database."""

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.StartDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified database."""

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.StopDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified database."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.MoveDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.DeleteDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified database."""

    Restore: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.RestoreBackupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Restores the specified backup"""

    Backup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.BackupDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

class DatabaseServiceAsyncStub:
    """A set of methods for managing databases."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.GetDatabaseRequest,
        yandex.cloud.ydb.v1.database_pb2.Database,
    ]
    """Returns the specified database."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.ListDatabasesRequest,
        yandex.cloud.ydb.v1.database_service_pb2.ListDatabasesResponse,
    ]
    """Retrieves a list of databases."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.CreateDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new database."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.UpdateDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Modifies the specified database."""

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.StartDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified database."""

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.StopDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified database."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.MoveDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.DeleteDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified database."""

    Restore: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.RestoreBackupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Restores the specified backup"""

    Backup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.database_service_pb2.BackupDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

class DatabaseServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing databases."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.GetDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ydb.v1.database_pb2.Database, collections.abc.Awaitable[yandex.cloud.ydb.v1.database_pb2.Database]]:
        """Returns the specified database."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.ListDatabasesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ydb.v1.database_service_pb2.ListDatabasesResponse, collections.abc.Awaitable[yandex.cloud.ydb.v1.database_service_pb2.ListDatabasesResponse]]:
        """Retrieves a list of databases."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.CreateDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new database."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.UpdateDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Modifies the specified database."""

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.StartDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts the specified database."""

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.StopDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops the specified database."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.MoveDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]: ...

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.DeleteDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified database."""

    @abc.abstractmethod
    def Restore(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.RestoreBackupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Restores the specified backup"""

    @abc.abstractmethod
    def Backup(
        self,
        request: yandex.cloud.ydb.v1.database_service_pb2.BackupDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

def add_DatabaseServiceServicer_to_server(servicer: DatabaseServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/pim/v1/saas/product_instance.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/pim/v1/saas/product_instance.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/marketplace/pim/v1/saas/product_instance.proto\x12$yandex.cloud.marketplace.pim.v1.saas\x1a\x1fgoogle/protobuf/timestamp.proto\"\x90\x04\n\x0fProductInstance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12I\n\rresource_type\x18\x03 \x01(\x0e\x32\x32.yandex.cloud.marketplace.pim.v1.saas.ResourceType\x12\x66\n\x11resource_metadata\x18\x04 \x03(\x0b\x32K.yandex.cloud.marketplace.pim.v1.saas.ProductInstance.ResourceMetadataEntry\x12:\n\x05state\x18\x05 \x01(\x0e\x32+.yandex.cloud.marketplace.pim.v1.saas.State\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\tsaas_info\x18\x08 \x01(\x0b\x32..yandex.cloud.marketplace.pim.v1.saas.SaasInfoH\x00\x1a\x37\n\x15ResourceMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rresource_info\"\x8b\x01\n\x08SaasInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x46\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x38.yandex.cloud.marketplace.pim.v1.saas.SaasInfo.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*s\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tACTIVATED\x10\x01\x12\x0f\n\x0b\x44\x45\x41\x43TIVATED\x10\x02\x12\x16\n\x12PENDING_ACTIVATION\x10\x03\x12\x0e\n\nDEPRECATED\x10\x04\x12\x0b\n\x07\x44\x45LETED\x10\x05*]\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAAS\x10\x01\x12\x07\n\x03K8S\x10\x02\x12\x0b\n\x07\x43OMPUTE\x10\x03\x12\x0e\n\nCLOUD_APPS\x10\x04\x42y\n(yandex.cloud.api.marketplace.pim.v1.saasZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/pim/v1/saas;saasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.pim.v1.saas.product_instance_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.marketplace.pim.v1.saasZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/pim/v1/saas;saas'
  _globals['_PRODUCTINSTANCE_RESOURCEMETADATAENTRY']._loaded_options = None
  _globals['_PRODUCTINSTANCE_RESOURCEMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_SAASINFO_DATAENTRY']._loaded_options = None
  _globals['_SAASINFO_DATAENTRY']._serialized_options = b'8\001'
  _globals['_STATE']._serialized_start=807
  _globals['_STATE']._serialized_end=922
  _globals['_RESOURCETYPE']._serialized_start=924
  _globals['_RESOURCETYPE']._serialized_end=1017
  _globals['_PRODUCTINSTANCE']._serialized_start=135
  _globals['_PRODUCTINSTANCE']._serialized_end=663
  _globals['_PRODUCTINSTANCE_RESOURCEMETADATAENTRY']._serialized_start=591
  _globals['_PRODUCTINSTANCE_RESOURCEMETADATAENTRY']._serialized_end=646
  _globals['_SAASINFO']._serialized_start=666
  _globals['_SAASINFO']._serialized_end=805
  _globals['_SAASINFO_DATAENTRY']._serialized_start=762
  _globals['_SAASINFO_DATAENTRY']._serialized_end=805
# @@protoc_insertion_point(module_scope)
